@@ -23,16 +23,18 @@ class RegisteredBindingMetaClass(type):
             binding_class.stream = stream
             binding_class._registred_actions = {}
 
+            binding_class._lazy = binding_class()
+
             if (
                 binding_class.model and
-                getattr(binding_class, 'post_save_connect', False) == True and
+                getattr(binding_class, 'post_save_connect', False) and
                 hasattr(binding_class, 'post_save')
             ):
                 post_save.connect(binding_class.post_save, sender=binding_class.model)
 
             if (
                 binding_class.model and
-                getattr(binding_class, 'post_delete_connect', False) == True and
+                getattr(binding_class, 'post_delete_connect', False) and
                 hasattr(binding_class, 'post_delete')
             ):
                 post_delete.connect(binding_class.post_delete, sender=binding_class.model)
